/* JessieRSAPrivateKey.java -- simple RSA private key.
   Copyright (C) 2003  Casey Marshall <rsdio@metastatic.org>

This file is a part of Jessie.

Jessie is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

Jessie is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with Jessie; if not, write to the

   Free Software Foundation, Inc.,
   59 Temple Place, Suite 330,
   Boston, MA  02111-1307
   USA  */


package org.metastatic.jessie.provider;

import java.math.BigInteger;
import java.security.interfaces.RSAPrivateKey;

class JessieRSAPrivateKey implements RSAPrivateKey
{

  // Fields.
  // -------------------------------------------------------------------------

  private final BigInteger modulus;
  private final BigInteger exponent;

  // Constructor.
  // -------------------------------------------------------------------------

  JessieRSAPrivateKey(BigInteger modulus, BigInteger exponent)
  {
    this.modulus = modulus;
    this.exponent = exponent;
  }

  // Instance methods.
  // -------------------------------------------------------------------------

  public String getAlgorithm()
  {
    return "RSA";
  }

  public String getFormat()
  {
    return "NONE";
  }

  public byte[] getEncoded()
  {
    return null;
  }

  public BigInteger getModulus()
  {
    return modulus;
  }

  public BigInteger getPrivateExponent()
  {
    return exponent;
  }

  public String toString()
  {
    String nl = System.getProperty("line.separator");
    return "RSAPrivateKey {" + nl +
      "  modulus = " + modulus.toString(16) + ";" + nl +
      "  exponent = " + exponent.toString(16) + ";" + nl +
      "};";
  }
}
